# eric7.Project.ProjectBrowserSortFilterProxyModel

Module implementing the browser sort filter proxy model.

### Global Attributes

None

### Classes

ProjectBrowserSortFilterProxyModel | Class implementing the browser sort filter proxy model.

### Functions

None

## ProjectBrowserSortFilterProxyModel

Class implementing the browser sort filter proxy model.

### Derived from

BrowserSortFilterProxyModel

### Class Attributes

None

### Class Methods

None

### Methods

ProjectBrowserSortFilterProxyModel | Constructor
filterAcceptsRow | Public method to filter rows.

### Static Methods

None

#### ProjectBrowserSortFilterProxyModel (Constructor)

ProjectBrowserSortFilterProxyModel(filterType, parent=None)

Constructor

filterType (str)
  type of filter to apply
parent (QObject)
  reference to the parent object

#### ProjectBrowserSortFilterProxyModel.filterAcceptsRow

filterAcceptsRow(source_row, source_parent)

Public method to filter rows.

It implements a filter to suppress the display of non public classes, methods and attributes.

source_row (int)
  row number (in the source model) of item
source_parent (QModelIndex)
  index of parent item (in the source model) of item

Return:
  flag indicating, if the item should be shown

Return Type:
  bool

Up